==> haskell-word-wrap-0.4.1-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-word-wrap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 word-wrap
version:              0.4.1
visibility:           public
id:                   word-wrap-0.4.1-Gwj7uJquens1EI8Bkdg7Xy
key:                  word-wrap-0.4.1-Gwj7uJquens1EI8Bkdg7Xy
license:              BSD-3-Clause
copyright:            2017 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
homepage:             https://github.com/jtdaugherty/word-wrap/
synopsis:             A library for word-wrapping
description:          A library for wrapping long lines of text.
category:             Text
abi:                  8c6f942b7ef120c71e5cb418723ba542
exposed:              True
exposed-modules:      Text.Wrap
import-dirs:          /usr/lib/ghc-8.8.1/site-local/word-wrap-0.4.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/word-wrap-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/word-wrap-0.4.1
hs-libraries:         HSword-wrap-0.4.1-Gwj7uJquens1EI8Bkdg7Xy
depends:              base-4.13.0.0 text-1.2.4.0
haddock-interfaces:   /usr/share/doc/haskell-word-wrap/html/word-wrap.haddock
haddock-html:         /usr/share/doc/haskell-word-wrap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-word-wrap-0.4.1-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-word-wrap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 word-wrap
version:              0.4.1
visibility:           public
id:                   word-wrap-0.4.1-J4NMBCS0rbL87ICo8R1wJP
key:                  word-wrap-0.4.1-J4NMBCS0rbL87ICo8R1wJP
license:              BSD-3-Clause
copyright:            2017 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
homepage:             https://github.com/jtdaugherty/word-wrap/
synopsis:             A library for word-wrapping
description:          A library for wrapping long lines of text.
category:             Text
abi:                  c62e0b82bd23a9bd9d688e2eeca0e2ed
exposed:              True
exposed-modules:      Text.Wrap
import-dirs:          /usr/lib/ghc-8.8.1/site-local/word-wrap-0.4.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/word-wrap-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/word-wrap-0.4.1
hs-libraries:         HSword-wrap-0.4.1-J4NMBCS0rbL87ICo8R1wJP
depends:              base-4.13.0.0 text-1.2.4.0
haddock-interfaces:   /usr/share/doc/haskell-word-wrap/html/word-wrap.haddock
haddock-html:         /usr/share/doc/haskell-word-wrap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
